@@ -1,9 +1,10 @@
-# $Id: /mirror/code/XML-Atom/trunk/lib/XML/Atom/Base.pm 4088 2006-08-27T05:50:44.603134Z miyagawa  $
+# $Id: /mirror/code/XML-Atom/trunk/lib/XML/Atom/Base.pm 5342 2006-09-16T06:39:51.745764Z miyagawa  $
 
 package XML::Atom::Base;
 use strict;
 use base qw( XML::Atom::ErrorHandler Class::Data::Inheritable );
 
+use Encode;
 use XML::Atom;
 use XML::Atom::Util qw( set_ns first nodelist childlist create_element remove_default_ns );
 
@@ -318,4 +319,9 @@ sub as_xml {
     }
 }
 
+sub as_xml_utf8 {
+    my $obj = shift;
+    Encode::encode_utf8($obj->as_xml);
+}
+
 1;
